// $ANTLR 2.7.7 (20060906): "groovy.g" -> "GroovyRecognizer.java"$

package org.codehaus.groovy.antlr.parser;
import org.codehaus.groovy.antlr.*;
import java.util.*;
import java.io.InputStream;
import java.io.Reader;
import antlr.InputBuffer;
import antlr.LexerSharedInputState;
import antlr.CommonToken;
import org.codehaus.groovy.GroovyBugError;
import antlr.TokenStreamRecognitionException;

public interface GroovyTokenTypes {
	int EOF = 1;
	int NULL_TREE_LOOKAHEAD = 3;
	int BLOCK = 4;
	int MODIFIERS = 5;
	int OBJBLOCK = 6;
	int SLIST = 7;
	int METHOD_DEF = 8;
	int VARIABLE_DEF = 9;
	int INSTANCE_INIT = 10;
	int STATIC_INIT = 11;
	int TYPE = 12;
	int CLASS_DEF = 13;
	int INTERFACE_DEF = 14;
	int PACKAGE_DEF = 15;
	int ARRAY_DECLARATOR = 16;
	int EXTENDS_CLAUSE = 17;
	int IMPLEMENTS_CLAUSE = 18;
	int PARAMETERS = 19;
	int PARAMETER_DEF = 20;
	int LABELED_STAT = 21;
	int TYPECAST = 22;
	int INDEX_OP = 23;
	int POST_INC = 24;
	int POST_DEC = 25;
	int METHOD_CALL = 26;
	int EXPR = 27;
	int IMPORT = 28;
	int UNARY_MINUS = 29;
	int UNARY_PLUS = 30;
	int CASE_GROUP = 31;
	int ELIST = 32;
	int FOR_INIT = 33;
	int FOR_CONDITION = 34;
	int FOR_ITERATOR = 35;
	int EMPTY_STAT = 36;
	int FINAL = 37;
	int ABSTRACT = 38;
	int UNUSED_GOTO = 39;
	int UNUSED_CONST = 40;
	int UNUSED_DO = 41;
	int STRICTFP = 42;
	int SUPER_CTOR_CALL = 43;
	int CTOR_CALL = 44;
	int CTOR_IDENT = 45;
	int VARIABLE_PARAMETER_DEF = 46;
	int STRING_CONSTRUCTOR = 47;
	int STRING_CTOR_MIDDLE = 48;
	int CLOSABLE_BLOCK = 49;
	int IMPLICIT_PARAMETERS = 50;
	int SELECT_SLOT = 51;
	int DYNAMIC_MEMBER = 52;
	int LABELED_ARG = 53;
	int SPREAD_ARG = 54;
	int SPREAD_MAP_ARG = 55;
	int LIST_CONSTRUCTOR = 56;
	int MAP_CONSTRUCTOR = 57;
	int FOR_IN_ITERABLE = 58;
	int STATIC_IMPORT = 59;
	int ENUM_DEF = 60;
	int ENUM_CONSTANT_DEF = 61;
	int FOR_EACH_CLAUSE = 62;
	int ANNOTATION_DEF = 63;
	int ANNOTATIONS = 64;
	int ANNOTATION = 65;
	int ANNOTATION_MEMBER_VALUE_PAIR = 66;
	int ANNOTATION_FIELD_DEF = 67;
	int ANNOTATION_ARRAY_INIT = 68;
	int TYPE_ARGUMENTS = 69;
	int TYPE_ARGUMENT = 70;
	int TYPE_PARAMETERS = 71;
	int TYPE_PARAMETER = 72;
	int WILDCARD_TYPE = 73;
	int TYPE_UPPER_BOUNDS = 74;
	int TYPE_LOWER_BOUNDS = 75;
	int CLOSURE_LIST = 76;
	int SH_COMMENT = 77;
	int LITERAL_package = 78;
	int LITERAL_import = 79;
	int LITERAL_static = 80;
	int LITERAL_def = 81;
	int LBRACK = 82;
	int RBRACK = 83;
	int IDENT = 84;
	int STRING_LITERAL = 85;
	int LT = 86;
	int DOT = 87;
	int LPAREN = 88;
	int LITERAL_class = 89;
	int LITERAL_interface = 90;
	int LITERAL_enum = 91;
	int AT = 92;
	int QUESTION = 93;
	int LITERAL_extends = 94;
	int LITERAL_super = 95;
	int COMMA = 96;
	int GT = 97;
	int SR = 98;
	int BSR = 99;
	int LITERAL_void = 100;
	int LITERAL_boolean = 101;
	int LITERAL_byte = 102;
	int LITERAL_char = 103;
	int LITERAL_short = 104;
	int LITERAL_int = 105;
	int LITERAL_float = 106;
	int LITERAL_long = 107;
	int LITERAL_double = 108;
	int STAR = 109;
	int LITERAL_as = 110;
	int LITERAL_private = 111;
	int LITERAL_public = 112;
	int LITERAL_protected = 113;
	int LITERAL_transient = 114;
	int LITERAL_native = 115;
	int LITERAL_threadsafe = 116;
	int LITERAL_synchronized = 117;
	int LITERAL_volatile = 118;
	int RPAREN = 119;
	int ASSIGN = 120;
	int BAND = 121;
	int LCURLY = 122;
	int RCURLY = 123;
	int SEMI = 124;
	int NLS = 125;
	int LITERAL_default = 126;
	int LITERAL_throws = 127;
	int LITERAL_implements = 128;
	int LITERAL_this = 129;
	int TRIPLE_DOT = 130;
	int CLOSABLE_BLOCK_OP = 131;
	int COLON = 132;
	int LITERAL_if = 133;
	int LITERAL_else = 134;
	int LITERAL_while = 135;
	int LITERAL_switch = 136;
	int LITERAL_for = 137;
	int LITERAL_in = 138;
	int LITERAL_return = 139;
	int LITERAL_break = 140;
	int LITERAL_continue = 141;
	int LITERAL_throw = 142;
	int LITERAL_assert = 143;
	int PLUS = 144;
	int MINUS = 145;
	int LITERAL_case = 146;
	int LITERAL_try = 147;
	int LITERAL_finally = 148;
	int LITERAL_catch = 149;
	int SPREAD_DOT = 150;
	int OPTIONAL_DOT = 151;
	int MEMBER_POINTER = 152;
	int LITERAL_false = 153;
	int LITERAL_instanceof = 154;
	int LITERAL_new = 155;
	int LITERAL_null = 156;
	int LITERAL_true = 157;
	int PLUS_ASSIGN = 158;
	int MINUS_ASSIGN = 159;
	int STAR_ASSIGN = 160;
	int DIV_ASSIGN = 161;
	int MOD_ASSIGN = 162;
	int SR_ASSIGN = 163;
	int BSR_ASSIGN = 164;
	int SL_ASSIGN = 165;
	int BAND_ASSIGN = 166;
	int BXOR_ASSIGN = 167;
	int BOR_ASSIGN = 168;
	int STAR_STAR_ASSIGN = 169;
	int ELVIS_OPERATOR = 170;
	int LOR = 171;
	int LAND = 172;
	int BOR = 173;
	int BXOR = 174;
	int REGEX_FIND = 175;
	int REGEX_MATCH = 176;
	int NOT_EQUAL = 177;
	int EQUAL = 178;
	int COMPARE_TO = 179;
	int LE = 180;
	int GE = 181;
	int SL = 182;
	int RANGE_INCLUSIVE = 183;
	int RANGE_EXCLUSIVE = 184;
	int INC = 185;
	int DIV = 186;
	int MOD = 187;
	int DEC = 188;
	int STAR_STAR = 189;
	int BNOT = 190;
	int LNOT = 191;
	int STRING_CTOR_START = 192;
	int STRING_CTOR_END = 193;
	int NUM_INT = 194;
	int NUM_FLOAT = 195;
	int NUM_LONG = 196;
	int NUM_DOUBLE = 197;
	int NUM_BIG_INT = 198;
	int NUM_BIG_DECIMAL = 199;
	int DOLLAR = 200;
	int WS = 201;
	int ONE_NL = 202;
	int SL_COMMENT = 203;
	int ML_COMMENT = 204;
	int STRING_CH = 205;
	int REGEXP_LITERAL = 206;
	int REGEXP_CTOR_END = 207;
	int REGEXP_SYMBOL = 208;
	int ESC = 209;
	int STRING_NL = 210;
	int HEX_DIGIT = 211;
	int VOCAB = 212;
	int LETTER = 213;
	int DIGIT = 214;
	int EXPONENT = 215;
	int FLOAT_SUFFIX = 216;
	int BIG_SUFFIX = 217;
}
